@@ -30,6 +30,7 @@ ResponseStrT = Union[Awaitable[str], str]
 ResponseBoolT = Union[Awaitable[bool], bool]
 ResponseListT = Union[Awaitable[list], list]
 ResponseZ = Union[List[str], List[Tuple[str, float]]]
+ResponseJSON = Union[List, Dict[str, Any]]
 
 
 logger = logging.getLogger('redis_extensions')
@@ -246,7 +247,7 @@ class StrictRedisExtensions(BaseRedisExpires, StrictRedis):
         # As of Redis version 6.2.0, this command is regarded as deprecated.
         # It can be replaced by SET with the GET argument when migrating or writing new code.
         warnings.warn(
-            f"{self.__class__.__name__}.getsetex() is deprecated. "
+            f"{self.__class__.__name__}.getsetex() is deprecated since Redis version 6.2.0. "
             f"Use {self.__class__.__name__}.set() with the GET/EX argument instead.",
             DeprecationWarning,
             stacklevel=2,
@@ -261,7 +262,7 @@ class StrictRedisExtensions(BaseRedisExpires, StrictRedis):
         # As of Redis version 6.2.0, this command is regarded as deprecated.
         # It can be replaced by SET with the GET argument when migrating or writing new code.
         warnings.warn(
-            f"{self.__class__.__name__}.getorset() is deprecated. "
+            f"{self.__class__.__name__}.getorset() is deprecated since Redis version 6.2.0. "
             f"Use {self.__class__.__name__}.set() with the GET/NX argument instead.",
             DeprecationWarning,
             stacklevel=2,
@@ -276,7 +277,7 @@ class StrictRedisExtensions(BaseRedisExpires, StrictRedis):
         # As of Redis version 6.2.0, this command is regarded as deprecated.
         # It can be replaced by SET with the GET argument when migrating or writing new code.
         warnings.warn(
-            f"{self.__class__.__name__}.getorsetex() is deprecated. "
+            f"{self.__class__.__name__}.getorsetex() is deprecated since Redis version 6.2.0. "
             f"Use {self.__class__.__name__}.set() with the GET/EX/NX argument instead.",
             DeprecationWarning,
             stacklevel=2,
@@ -411,7 +412,7 @@ class StrictRedisExtensions(BaseRedisExpires, StrictRedis):
         # SPOP
         # Starting with Redis version 3.2.0: Added the count argument.
         warnings.warn(
-            f"{self.__class__.__name__}.multispop() is deprecated. "
+            f"{self.__class__.__name__}.multispop() is deprecated since Redis version 3.2.0. "
             f"Use {self.__class__.__name__}.spop() with the COUNT argument instead.",
             DeprecationWarning,
             stacklevel=2,
@@ -685,9 +686,12 @@ class StrictRedisExtensions(BaseRedisExpires, StrictRedis):
         """
         return self.setnx(name, json.dumps(value, **self.__json_params(cls, json_params)))
 
-    def get_json(self, name: str, default: str = '{}') -> Dict[str, Any]:
+    def get_json(self, name: str, default: str = '{}') -> ResponseJSON:
         return json.loads(self.get(name) or default)
 
+    def get_list(self, name: str) -> List:
+        return self.get_json(name, default='[]')
+
     def hset_json(self, name: str, key: Optional[str] = None, value: Optional[EncodableT] = None, mapping: Optional[dict] = None, items: Optional[list] = None, cls: Optional[Type[json.JSONDecoder]] = None, json_params: Dict[str, Any] = None) -> ResponseIntT:
         if key is None and not mapping and not items:
             raise DataError("'hsetjson' with no key value pairs")
@@ -703,8 +707,11 @@ class StrictRedisExtensions(BaseRedisExpires, StrictRedis):
         return self.hsetnx(name, key, json.dumps(value, **self.__json_params(cls, json_params)))
 
     def hmset_json(self, name: str, mapping: Dict[str, Any], cls: Optional[Type[json.JSONDecoder]] = None, json_params: Dict[str, Any] = None) -> ResponseStrT:
+        # HMSET
+        # As of Redis version 4.0.0, this command is regarded as deprecated.
+        # It can be replaced by HSET with multiple field-value pairs when migrating or writing new code.
         warnings.warn(
-            f"{self.__class__.__name__}.hmsetjson() is deprecated. "
+            f"{self.__class__.__name__}.hmsetjson() is deprecated since Redis version 4.0.0. "
             f"Use {self.__class__.__name__}.hsetjson() instead.",
             DeprecationWarning,
             stacklevel=2,
@@ -1343,10 +1350,11 @@ class StrictRedisExtensions(BaseRedisExpires, StrictRedis):
     hvalsstr = hvals_str
     hgetallstr = hgetall_str
     # JSON
-    setjson = set_json
-    setexjson = setex_json
-    setnxjson = setnx_json
+    setlist = set_list = setjson = set_json
+    setexlist = setex_list = setexjson = setex_json
+    setnxlist = setnx_list = setnxjson = setnx_json
     getjson = get_json
+    getlist = get_list
     hsetjson = hset_json
     hsetnxjson = hsetnx_json
     hmsetjson = hmset_json
